@@ -30,9 +30,7 @@ class WowProfileApi(Api):
         self, region, locale, access_token, realm_id, character_id
     ):
         """Return a protected profile summary for a character."""
-        resource = (
-            f"/profile/user/wow/protected-character/{realm_id}-{character_id}"
-        )
+        resource = f"/profile/user/wow/protected-character/{realm_id}-{character_id}"
         query_params = {
             "namespace": f"profile-{region}",
             "locale": locale,
@@ -50,9 +48,7 @@ class WowProfileApi(Api):
         }
         return super().get_resource(resource, region, query_params)
 
-    def get_account_mounts_collection_summary(
-        self, region, locale, access_token
-    ):
+    def get_account_mounts_collection_summary(self, region, locale, access_token):
         """Return a summary of the mounts an account has obtained."""
         resource = "/profile/user/wow/collections/mounts"
         query_params = {
@@ -62,9 +58,7 @@ class WowProfileApi(Api):
         }
         return super().get_resource(resource, region, query_params)
 
-    def get_account_pets_collection_summary(
-        self, region, locale, access_token
-    ):
+    def get_account_pets_collection_summary(self, region, locale, access_token):
         """Return a summary of the battle pets an account has obtained."""
         resource = "/profile/user/wow/collections/pets"
         query_params = {
@@ -98,9 +92,7 @@ class WowProfileApi(Api):
         self, region, locale, realm_slug, character_name
     ):
         """Return a summary of a character's appearance settings."""
-        resource = (
-            f"/profile/wow/character/{realm_slug}/{character_name}/appearance"
-        )
+        resource = f"/profile/wow/character/{realm_slug}/{character_name}/appearance"
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
@@ -110,9 +102,7 @@ class WowProfileApi(Api):
         self, region, locale, realm_slug, character_name
     ):
         """Return an index of collection types for a character."""
-        resource = (
-            f"/profile/wow/character/{realm_slug}/{character_name}/collections"
-        )
+        resource = f"/profile/wow/character/{realm_slug}/{character_name}/collections"
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
@@ -120,7 +110,9 @@ class WowProfileApi(Api):
         self, region, locale, realm_slug, character_name
     ):
         """Return a summary of the mounts a character has obtained."""
-        resource = f"/profile/wow/character/{realm_slug}/{character_name}/collections/mounts"
+        resource = (
+            f"/profile/wow/character/{realm_slug}/{character_name}/collections/mounts"
+        )
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
@@ -128,7 +120,9 @@ class WowProfileApi(Api):
         self, region, locale, realm_slug, character_name
     ):
         """Return a summary of the battle pets a character has obtained."""
-        resource = f"/profile/wow/character/{realm_slug}/{character_name}/collections/pets"
+        resource = (
+            f"/profile/wow/character/{realm_slug}/{character_name}/collections/pets"
+        )
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
@@ -138,23 +132,23 @@ class WowProfileApi(Api):
         self, region, locale, realm_slug, character_name
     ):
         """Return a summary of a character's encounters."""
-        resource = (
-            f"/profile/wow/character/{realm_slug}/{character_name}/encounters"
-        )
+        resource = f"/profile/wow/character/{realm_slug}/{character_name}/encounters"
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
-    def get_character_dungeons(
-        self, region, locale, realm_slug, character_name
-    ):
+    def get_character_dungeons(self, region, locale, realm_slug, character_name):
         """Return a summary of a character's completed dungeons."""
-        resource = f"/profile/wow/character/{realm_slug}/{character_name}/encounters/dungeons"
+        resource = (
+            f"/profile/wow/character/{realm_slug}/{character_name}/encounters/dungeons"
+        )
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
     def get_character_raids(self, region, locale, realm_slug, character_name):
         """Return a summary of a character's completed raids."""
-        resource = f"/profile/wow/character/{realm_slug}/{character_name}/encounters/raids"
+        resource = (
+            f"/profile/wow/character/{realm_slug}/{character_name}/encounters/raids"
+        )
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
@@ -164,9 +158,7 @@ class WowProfileApi(Api):
         self, region, locale, realm_slug, character_name
     ):
         """Return a summary of the items equipped by a character."""
-        resource = (
-            f"/profile/wow/character/{realm_slug}/{character_name}/equipment"
-        )
+        resource = f"/profile/wow/character/{realm_slug}/{character_name}/equipment"
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
@@ -176,19 +168,17 @@ class WowProfileApi(Api):
         self, region, locale, realm_slug, character_name
     ):
         """If the character is a hunter, returns a summary of the character's hunter pets."""
-        resource = (
-            f"/profile/wow/character/{realm_slug}/{character_name}/hunter-pets"
-        )
+        resource = f"/profile/wow/character/{realm_slug}/{character_name}/hunter-pets"
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
     # Character Media API
 
-    def get_character_media_summary(
-        self, region, locale, realm_slug, character_name
-    ):
+    def get_character_media_summary(self, region, locale, realm_slug, character_name):
         """Return a summary of the media assets available for a character (such as an avatar render)."""
-        resource = f"/profile/wow/character/{realm_slug}/{character_name}/character-media"
+        resource = (
+            f"/profile/wow/character/{realm_slug}/{character_name}/character-media"
+        )
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
@@ -216,29 +206,21 @@ class WowProfileApi(Api):
         self, region, locale, realm_slug, character_name
     ):
         """Return a summary of professions for a character."""
-        resource = (
-            f"/profile/wow/character/{realm_slug}/{character_name}/professions"
-        )
+        resource = f"/profile/wow/character/{realm_slug}/{character_name}/professions"
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
     # Character Profile API
 
-    def get_character_profile_summary(
-        self, region, locale, realm_slug, character_name
-    ):
+    def get_character_profile_summary(self, region, locale, realm_slug, character_name):
         """Return a profile summary for a character."""
         resource = f"/profile/wow/character/{realm_slug}/{character_name}"
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
-    def get_character_profile_status(
-        self, region, locale, realm_slug, character_name
-    ):
+    def get_character_profile_status(self, region, locale, realm_slug, character_name):
         """Return the status and a unique ID for a character."""
-        resource = (
-            f"/profile/wow/character/{realm_slug}/{character_name}/status"
-        )
+        resource = f"/profile/wow/character/{realm_slug}/{character_name}/status"
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
@@ -252,13 +234,9 @@ class WowProfileApi(Api):
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
-    def get_character_pvp_summary(
-        self, region, locale, realm_slug, character_name
-    ):
+    def get_character_pvp_summary(self, region, locale, realm_slug, character_name):
         """Return a Pvp summary for a character."""
-        resource = (
-            f"/profile/wow/character/{realm_slug}/{character_name}/pvp-summary"
-        )
+        resource = f"/profile/wow/character/{realm_slug}/{character_name}/pvp-summary"
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
@@ -266,9 +244,7 @@ class WowProfileApi(Api):
 
     def get_character_quests(self, region, locale, realm_slug, character_name):
         """Return a character's active quests as well as a link to the character's completed quests."""
-        resource = (
-            f"/profile/wow/character/{realm_slug}/{character_name}/quests"
-        )
+        resource = f"/profile/wow/character/{realm_slug}/{character_name}/quests"
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
@@ -276,7 +252,9 @@ class WowProfileApi(Api):
         self, region, locale, realm_slug, character_name
     ):
         """Return a list of quests that a character has completed."""
-        resource = f"/profile/wow/character/{realm_slug}/{character_name}/quests/completed"
+        resource = (
+            f"/profile/wow/character/{realm_slug}/{character_name}/quests/completed"
+        )
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
@@ -286,9 +264,7 @@ class WowProfileApi(Api):
         self, region, locale, realm_slug, character_name
     ):
         """Return a summary of a character's reputations."""
-        resource = (
-            f"/profile/wow/character/{realm_slug}/{character_name}/reputations"
-        )
+        resource = f"/profile/wow/character/{realm_slug}/{character_name}/reputations"
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
@@ -298,7 +274,9 @@ class WowProfileApi(Api):
         self, region, locale, realm_slug, character_name
     ):
         """Return a summary of a character's specializations."""
-        resource = f"/profile/wow/character/{realm_slug}/{character_name}/specializations"
+        resource = (
+            f"/profile/wow/character/{realm_slug}/{character_name}/specializations"
+        )
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
@@ -308,21 +286,15 @@ class WowProfileApi(Api):
         self, region, locale, realm_slug, character_name
     ):
         """Return a statistics summary for a character."""
-        resource = (
-            f"/profile/wow/character/{realm_slug}/{character_name}/statistics"
-        )
+        resource = f"/profile/wow/character/{realm_slug}/{character_name}/statistics"
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
     # Character Titles API
 
-    def get_character_titles_summary(
-        self, region, locale, realm_slug, character_name
-    ):
+    def get_character_titles_summary(self, region, locale, realm_slug, character_name):
         """Return a summary of titles a character has obtained."""
-        resource = (
-            f"/profile/wow/character/{realm_slug}/{character_name}/titles"
-        )
+        resource = f"/profile/wow/character/{realm_slug}/{character_name}/titles"
         query_params = {"namespace": f"profile-{region}", "locale": locale}
         return super().get_resource(resource, region, query_params)
 
